@@ -144,11 +144,9 @@ class ArcReturnJSONObject:
 
         log.debug(u'   Result : %s' % (self.get_result()))
         log.debug(u'   Message : %s' % (self.get_message()))
-        log.debug(u'   Data')
+        log.debug(u'   Data\n')
         if log_data:
             self.log_dict(self.get_data())
-        else:
-            log.debug(u'\n')
 
 
 
