@@ -44,7 +44,7 @@ class TimeitHttpClient:
         try:
             t = timeit.Timer(lambda : request_http())
             total_time = t.timeit(number=self.repeat_number)
-            log.debug(u'  %s execution average time : %.02f (%s repeat)' %
+            log.debug(u'  %s execution average time : %.02f (%s repeat)\n' %
                       (self.title, (total_time / self.repeat_number), self.repeat_number))
         except Exception as e:
             log.debug('Exception args : %s' % (e.args))
